@@ -1,5 +1,5 @@
 ﻿// PHZ
-// 2018-6-11
+// 2021-9-2
 
 #ifndef XOP_RTP_H
 #define XOP_RTP_H
@@ -11,6 +11,9 @@
 #define MAX_RTP_PAYLOAD_SIZE   1420 //1460  1500-20-12-8
 #define RTP_VERSION			   2
 #define RTP_TCP_HEAD_SIZE	   4
+#define RTP_VPX_HEAD_SIZE	   1
+
+#define RTP_HEADER_BIG_ENDIAN  0
 
 namespace xop
 {
@@ -24,14 +27,23 @@ enum TransportMode
 
 typedef struct _RTP_header
 {
+#if RTP_HEADER_BIG_ENDIAN
+	/* 大端序 */
+	unsigned char version   : 2;
+	unsigned char padding   : 1;
+	unsigned char extension : 1;
+	unsigned char csrc      : 4;
+	unsigned char marker    : 1;
+	unsigned char payload   : 7;
+#else
 	/* 小端序 */
-	unsigned char csrc:4;
-	unsigned char extension:1;
-	unsigned char padding:1;
-	unsigned char version:2;
-	unsigned char payload:7;
-	unsigned char marker:1;
-
+	unsigned char csrc      : 4;
+	unsigned char extension : 1;
+	unsigned char padding   : 1;
+	unsigned char version   : 2;
+	unsigned char payload   : 7;
+	unsigned char marker    : 1;
+#endif 
 	unsigned short seq;
 	unsigned int   ts;
 	unsigned int   ssrc;
@@ -67,6 +79,9 @@ struct RtpPacket
 		: data(new uint8_t[1600], std::default_delete<uint8_t[]>())
 	{
 		type = 0;
+		size = 0;
+		timestamp = 0;
+		last = 0;
 	}
 
 	std::shared_ptr<uint8_t> data;
